(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     69829,       1583]
NotebookOptionsPosition[     65820,       1523]
NotebookOutlinePosition[     66240,       1540]
CellTagsIndexPosition[     66197,       1537]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"19c3120b-2ac8-4eea-ad9f-e07fdfb682f6"],

Cell["Chapter 8, Section 8.2, Figure 8.3", "Section",
 CellChangeTimes->{{3.878562412934669*^9, 3.878562413354199*^9}, 
   3.878806195890608*^9, 
   3.8788925178202457`*^9},ExpressionUUID->"116b32ce-d651-44c4-a052-\
edcb74a1d02b"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0757cbff-c8b9-4496-aced-052489c24451"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", " ", "e_"}], "]"}], " ", ":=", " ", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878551288853799*^9, 3.8785512888598747`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"e1653a61-6b1c-42de-a1e8-135f0be0a02e"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b9b27efc-2e00-4c43-8ea3-cd301bfd5c4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\n", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", " ", "/.", " ", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", "\n", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", "\n", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.878551301888957*^9, 3.8785513018971653`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"539b69c8-8625-4600-adc5-c07ae65568da"],

Cell["\<\
Set the values of the asteroid\[CloseCurlyQuote]s semi-major axis and \
eccentricity.  This is specific for the 2:1 interior resonance.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878801704308281*^9, 3.878801749629154*^9}, 3.878803303684956*^9, {
   3.878819463837797*^9, 3.8788194665832376`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9b8ea8fc-ab2e-491a-af25-0c30d05ca6bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "/", "3"}], ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ae", "=", "0.2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.878559737940578*^9, 3.8785597663040123`*^9}, {
  3.878809425067333*^9, 3.878809425458521*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"ba917d24-c5bd-405b-8096-ef18d10a00c0"],

Cell["\<\
Set the colours to be used for the two orbits and associated positions of the \
asteroid and Jupiter.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1945fe94-8110-4045-9be7-32cbe9e3485e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8706884723044577`*^9, 3.8706884767572603`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"bccf7402-2890-4b34-bf7c-4604b5d4ae7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.870688484124298*^9, 3.870688503351976*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"dee6dc8b-7e87-49bc-a336-26c04af5ddd9"],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPathNonRotating", "Input"],
 " to show the paths in the non-rotating frame around the unit orbit and the \
resonant orbit, adding points at equal time intervals, ",
 StyleBox["dt", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8788194870588827`*^9, 3.878819502613019*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e82385bb-d636-4c19-8cab-b138bf7f95b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotPathNonRotating", "[", 
   RowBox[{"pl_List", ",", " ", "e_", ",", " ", "dt_"}], "]"}], " ", ":=", 
  "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "time", ",", " ", "p1", ",", " ", "p2", ",", "\[IndentingNewLine]", 
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"Apply", "[", 
        RowBox[{"Rational", ",", "pl"}], "]"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"pt", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pl", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", ">", " ", 
          RowBox[{"pl", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
         RowBox[{"pl", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
         RowBox[{"pl", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"sun", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.15", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], ",", 
      RowBox[{"porb", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"color2", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
        "]"}]}], ",", 
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pl", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", 
           RowBox[{"pl", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", "/", "3"}], ")"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"box", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1.1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.1", ",", 
             RowBox[{"-", "1.1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.1", ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1.1"}]}], "}"}]}], "}"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ptime", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"pt", "*", "2", "*", "Pi"}], ",", 
          RowBox[{"Pi", "/", "40"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"time", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"pt", "*", "2", "*", "Pi"}], ",", "dt"}], "}"}]}], "]"}]}], 
     ";", 
     RowBox[{"posvec", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "[", 
          RowBox[{"#", ",", "a", ",", "e"}], "]"}], "&"}], ",", "time"}], 
       "]"}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "posvec"}], "]"}]}], ";", 
     RowBox[{"rad", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}], 
         "&"}], ",", "posvec"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"jtemp", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"position", "[", 
         RowBox[{
          RowBox[{"meananom", "/", "2"}], ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"meananom", ",", "0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "dt"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"jpoints", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", 
             RowBox[{"Thickness", "[", "0.005", "]"}], "]"}], ",", "color2", 
            ",", 
            RowBox[{"Disk", "[", 
             RowBox[{"#", ",", "0.05"}], "]"}]}], "}"}], "]"}], "&"}], ",", 
        "jtemp"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"atemp", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"position", "[", 
         RowBox[{"meananom", ",", "aa", ",", "ae"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"meananom", ",", "0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "dt"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"apoints", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", "0.02", "]"}], ",", "color1", ",", 
            RowBox[{"Point", "[", "#", "]"}]}], "}"}], "]"}], "&"}], ",", 
        "atemp"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"posvec", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "[", 
          RowBox[{"#", ",", "a", ",", "e"}], "]"}], "&"}], ",", "ptime"}], 
       "]"}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "posvec"}], "]"}]}], ";", 
     RowBox[{"rad", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}], 
         "&"}], ",", "posvec"}], "]"}]}], ";", 
     RowBox[{"orbpts", " ", "=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "f", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "f", "]"}]}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p3", " ", "=", " ", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"orbpts", ",", 
        RowBox[{"Joined", "->", "True"}], ",", "\[IndentingNewLine]", 
        RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", 
        RowBox[{"Axes", "->", "None"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}]}], "]"}]}], 
     ";", 
     RowBox[{"Show", "[", 
      RowBox[{
      "box", ",", "sun", ",", "porb", ",", "jpoints", ",", "apoints", ",", 
       "p3", ",", "\[IndentingNewLine]", 
       RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}]}], "]"}]}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.8785515578240433`*^9, 3.878551562400597*^9}, {
   3.878805209383565*^9, 3.878805219168153*^9}, {3.878806353542527*^9, 
   3.878806431241819*^9}, {3.878806571148014*^9, 3.878806582563015*^9}, {
   3.878806677241661*^9, 3.878806700850173*^9}, {3.878807065210823*^9, 
   3.878807094402457*^9}, {3.878807211673362*^9, 3.878807225143416*^9}, {
   3.8788072837509823`*^9, 3.8788073289128933`*^9}, {3.878807496312489*^9, 
   3.878807675427043*^9}, {3.878807964553898*^9, 3.878807967791876*^9}, {
   3.878808063507061*^9, 3.878808066191638*^9}, {3.878808780066029*^9, 
   3.878808786111225*^9}, {3.878808829357732*^9, 3.8788088298369427`*^9}, {
   3.878808984742545*^9, 3.878809035758087*^9}, {3.878809153581646*^9, 
   3.878809171103488*^9}, 3.878809203676968*^9, {3.8788092935054007`*^9, 
   3.8788092987837477`*^9}, {3.878809469068515*^9, 3.87880948717144*^9}, {
   3.878809549747574*^9, 3.8788095584658012`*^9}, 3.878809622350808*^9, {
   3.878809720738461*^9, 3.87880974354491*^9}, {3.878809871621364*^9, 
   3.878809941604014*^9}, {3.878817696236095*^9, 3.878817704768483*^9}, {
   3.878817744896742*^9, 3.878817753236405*^9}, {3.878819508330567*^9, 
   3.878819513040954*^9}, {3.878819621766327*^9, 3.8788196228605137`*^9}, 
   3.878820207986219*^9, 3.878820297574974*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"df636d44-0d64-4c40-a000-18c6f1bd180d"],

Cell["\<\
Plot the paths in the non-rotating frame for the 2:1 resonance with points at \
time intervals of \[Pi]/4.  This is Fig.8.3a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878819122724942*^9, 3.878819149108246*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"45542096-61ae-4fd8-a06d-08cc0d684967"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pnonrot", " ", "=", " ", 
  RowBox[{"PlotPathNonRotating", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", " ", "0.2", ",", " ", 
    RowBox[{"Pi", "/", "4"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8785515864854727`*^9, 3.8785515864915943`*^9}, {
  3.8788161503909407`*^9, 3.878816150705078*^9}, {3.878819527507049*^9, 
  3.8788195415468273`*^9}, {3.878821093546665*^9, 3.878821093875739*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"4c6a7114-81b5-45fe-be3b-9e879f1d94fc"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
    1.1}, {-1.1, -1.1}}], 
   {PointSize[0.15], PointBox[{0, 0}]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], CircleBox[{0, 0}, 1]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{1., 0.}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.9238795325112867, 0.3826834323650898}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.7071067811865476, 0.7071067811865475}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.38268343236508984, 0.9238795325112867}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{6.123233995736766*^-17, 1.}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.3826834323650897, 0.9238795325112867}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.7071067811865475, 0.7071067811865476}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.9238795325112867, 0.38268343236508984}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-1., 1.2246467991473532*^-16}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.9238795325112868, -0.38268343236508967}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.7071067811865477, -0.7071067811865474}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-0.38268343236509034, -0.9238795325112865}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{-1.8369701987210297*^-16, -1.}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.38268343236509, -0.9238795325112866}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.7071067811865474, -0.7071067811865477}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{0.9238795325112865, -0.3826834323650904}, 0.05]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{1., -2.4492935982947064*^-16}, 0.05]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.5039684199579493, 0.}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.24155727517501757`, 0.5012857543232488}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.24877684075526632`, 0.6053950815696957}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.6227289741433344, 0.3796032612908802}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.7559526299369239, 7.55892096537123*^-17}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.6227289741433345, -0.3796032612908801}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.24877684075526663`, -0.6053950815696957}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.24155727517501716`, -0.5012857543232491}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.5039684199579493, -1.511784193074246*^-16}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.2415572751750179, 0.5012857543232486}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.24877684075526632`, 0.6053950815696957}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.6227289741433342, 0.37960326129088057`}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.7559526299369239, 2.267676289611369*^-16}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.6227289741433344, -0.3796032612908802}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.24877684075526676`, -0.6053950815696957}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.2415572751750166, -0.5012857543232495}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.5039684199579493, -3.023568386148492*^-16}]}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJyV1WtQVGUYB3ACDFFE8ELIqCGaqaODhairwIMJZqCDA4UJ5G3YFNGSNBER
EUWxmwGFOUIYJd6WBdPQRYWHizdSUFdQBJYFjsAWg6iIExaW9f73wx71Q8zs
8OHMOed9n/f//51Ryz8OVJqbmZllPf39+9+j23PZNudGMsPfpa0BBrVVI83R
9byX/iiXrs8aMPLdWD3NSx+4cPzFImobk7uxIKmBDmW97ni79gId6znubq3Q
UWak3SEL20rK6l3kNjWtjoZE+F3TrddSuN5as/in2+STVxv2XW41dX1qyImN
vEW9q1Sx49U1FNUVR3aPqmjmfIfCJ6vq6NjX8zP0/lqaE3Kxz++SjipXbvFb
1F5JFhmOq3f1a6SCIQ2h/f+4RC/XqLTKJ41UkjlaqagsJXfHD9/0rmiiqNC4
eerHGkrdc3m7Z3QzWTh12FsHHKa/ayO8pb+aKdjr1ejiwJWcNFPjYrlEonLt
0k7bhSqePsz+RF6mROt2rY1IiDvNnV6attGFErlO0d1Zn1rG09urW4vPSBS8
0ubm8Evl3LX8m6on6RKltexQtt+6yj19kxOUT5/3mXPK0U06Lcdk3y3dYSXR
+btOobvzq7ncrknxMK2Z1GMmrtsSVcOD8lwCfW2a6RVr68vttnX8tpX77H6r
m2j/uJzkki90bOXR21J5spGuHAp3ndSq5+QBs9dMrteTjX/iZn/bJlbEzC25
MLaBtg8Ouljh0MxLokqj/BbUU4b2sJmFjcSSxm34t6G1pOmas0DZIXFz8cRN
kf41lPB4uHvC6Tuc93j8gySXm3Q/41RS1yctHJSg2pgi3aAJQX8Wr3Bo5a/G
eeSOSrlObxQujN9zoJXfSdgd/HloJaVPGOXrM6KNyxY/rOuJLqew4KBI761t
rN48uzR+8znasCLLJ7yijUdWhVbdryuixJ/D1qRaGjhk1/2hET/+QoM2LPM9
+ZqBdQ9PeDWoDlBtZ31K2WQDd5+zjbHI2+dhj+ux4job739L3M/G5/cVz+cQ
vF8l3s/fY33nxfp4MtY/V6yfZfvje9j/IrF/ls2HCzA/ScyPMzFfvZgvJ2H+
H4j580CczzRxPnwN57dbnB+rcb7m4nx5hOn5cw7yYS/ywWyaH05EvjaJfPF+
0/zxUuTzgcgnuyO/CpFfPoJ83xP5ZocbIv/TRP7Z2dOkHzwY/ekV/eEv0a8U
0S8uRP+miv5xEfppKfrJjP72Ef3lbPQ7QPSbP0L/PUX/uQM+mEX+5wMvhR++
wg/+Ab44CV/Y6M9+4Q/LfGKjX3OFX2z0bYjwjY3+bfS5dyW+PPvsr7j+W73w
7wbu7w//DHh+Lvw7jvfvkfk3VOYfwb8e7K8b/q3C/r3hXw7m4w//bmN+L8G/
CszXAv7dwvzd4F+szD+F6fnRiRnifHfCP53MvwiZf/Q//dtimk86hvxWwL9T
yLfdC/w7gn5Ywr9S9Gcv/OuHftEL/JP1k/LR33aZf0fgn6z/z/jnCj+C4N8+
+FIP/4z+aGT+TYV/2+DX+zL/cmT+OWY5r02sL/IwXrfpFv5tx/2zZP7BV5b5
y8b1XYV/bli/F/ybhP1tg38y/zkR8zkI/2TfD87CfKvh307MPwz+yb5PLPt+
PePfaJy/L/wrQT5s4d8Z5Ocy/NuLfEXDv4My/1aY5pNnmOaXvU3zzbL8c5zC
pB8cMkz0x7xO+DcF/UqDf/no3zT4p0Y/reDfYfTXGv6p0G8/+Lca/SeZf+bw
Twk/vODfXvgyFv4dhT+n4J8En7Tw7wr8CpT5F/Nc//LP/gPB6Gjl
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.87855158737366*^9, 3.878561149701496*^9, 3.8785624883662786`*^9, 
   3.878809222553186*^9, 3.878809346004013*^9, 3.87880943970518*^9, {
   3.8788094730276747`*^9, 3.878809494314665*^9}, {3.8788097288712*^9, 
   3.878809748426724*^9}, 3.8788099536394*^9, 3.878815006453755*^9, 
   3.878816153638371*^9, 3.878817721599709*^9, 3.878819640391755*^9, 
   3.878819808727233*^9, {3.878820081335651*^9, 3.8788201018077497`*^9}, 
   3.878820413110523*^9, 3.8788204745622168`*^9, 3.878820741265739*^9, 
   3.8788210977738132`*^9, 3.878821191721653*^9, 3.8909872640552263`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"7840c6e3-907c-4207-a806-89d80075b7ae"]
}, Open  ]],

Cell["Define the labels to be used in the non-rotating frame plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8788192962883167`*^9, 3.8788193492535954`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2207161e-5767-423c-88d1-519c317c13bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jangles", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"0.88", "*", 
      RowBox[{"position", "[", 
       RowBox[{
        RowBox[{"meananom", "/", "2"}], ",", "1", ",", "0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"meananom", ",", "0", ",", 
       RowBox[{
        RowBox[{"4", "\[Pi]"}], "-", 
        RowBox[{"\[Pi]", "/", "4"}]}], ",", 
       RowBox[{"\[Pi]", "/", "4"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878814550970377*^9, 3.8788145573739*^9}, {
  3.878815491987842*^9, 3.8788154969549503`*^9}, {3.878815545115781*^9, 
  3.878815599758747*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"a4153d95-f66c-4fef-a902-6780e6849f9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jlabels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "\"\<D\>\"", ",", 
     "\"\<E\>\"", ",", "\"\<F\>\"", ",", "\"\<G\>\"", ",", "\"\<H\>\"", ",", 
     "\"\<I\>\"", ",", "\"\<J\>\"", ",", "\"\<K\>\"", ",", "\"\<L\>\"", ",", 
     "\"\<M\>\"", ",", "\"\<N\>\"", ",", "\"\<O\>\"", ",", "\"\<P\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878814592491756*^9, 3.878814708139413*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"cd3aea0b-6b73-4e3e-b390-316dfa5ec12c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jletters", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"jlabels", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"jangles", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "16"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8788147223071404`*^9, 3.87881479446423*^9}, {
   3.87881488708916*^9, 3.878814906125798*^9}, {3.8788149693110113`*^9, 
   3.878814997486682*^9}, {3.878815030882566*^9, 3.878815034256693*^9}, 
   3.878815522260725*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"825e2e3e-4a63-46cc-91b2-f58f2fde7328"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aangles", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"0.82", "*", 
      RowBox[{"position", "[", 
       RowBox[{"meananom", ",", "aa", ",", "ae"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"meananom", ",", "0", ",", 
       RowBox[{
        RowBox[{"4", "\[Pi]"}], "-", 
        RowBox[{"\[Pi]", "/", "4"}]}], ",", 
       RowBox[{"\[Pi]", "/", "4"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878814550970377*^9, 3.8788145573739*^9}, {
  3.878815491987842*^9, 3.8788154969549503`*^9}, {3.878815545115781*^9, 
  3.878815599758747*^9}, {3.8788156563555517`*^9, 3.878815679976108*^9}, {
  3.878815726234167*^9, 3.878815757919335*^9}, {3.8788159145170517`*^9, 
  3.878815917149996*^9}, {3.878815969691099*^9, 3.8788160808804417`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"50a2d504-96e4-4a76-b11f-6f31e53b0ac1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"alabels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<A,I\>\"", ",", "\"\<B,J\>\"", ",", "\"\<C,K\>\"", ",", "\"\<D,L\>\"",
      ",", "\"\<E,M\>\"", ",", "\"\<F,N\>\"", ",", "\"\<G,O\>\"", ",", 
     "\"\<H,P\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878814592491756*^9, 3.878814708139413*^9}, {
  3.8788156601911583`*^9, 3.878815661230501*^9}, {3.878815776454322*^9, 
  3.878815835013032*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"57c00776-ce55-46d5-bce6-b11c57d5c36b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aletters", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"alabels", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"aangles", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8788147223071404`*^9, 3.87881479446423*^9}, {
   3.87881488708916*^9, 3.878814906125798*^9}, {3.8788149693110113`*^9, 
   3.878814997486682*^9}, {3.878815030882566*^9, 3.878815034256693*^9}, 
   3.878815522260725*^9, {3.878815663630701*^9, 3.878815663725849*^9}, {
   3.878815849164174*^9, 3.878815869341135*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"3c89c47a-d412-4d4c-ba18-b92a686fa542"],

Cell["\<\
Add labels to help to identify the relative locations at each time step.  \
This is Fig.8.3a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878819122724942*^9, 3.878819219309181*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8a83918a-488d-47e9-92e2-38aeccfa6e92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pnonrot", ",", "jletters", ",", "aletters"}], "]"}]], "Input",
 CellChangeTimes->{{3.878815013055274*^9, 3.878815042313064*^9}, {
  3.8788158782166023`*^9, 3.8788158811012793`*^9}, {3.878816157891264*^9, 
  3.8788161580863333`*^9}, {3.8788195460356407`*^9, 3.878819547671105*^9}, {
  3.8788210873974047`*^9, 3.878821087920843*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"1d782ee5-6294-4d71-b7b9-499bb41f0461"],

Cell[BoxData[
 GraphicsBox[{{
    LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
     1.1}, {-1.1, -1.1}}], 
    {PointSize[0.15], PointBox[{0, 0}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], CircleBox[{0, 0}, 1]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{1., 0.}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.9238795325112867, 0.3826834323650898}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.7071067811865476, 0.7071067811865475}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.38268343236508984, 0.9238795325112867}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{6.123233995736766*^-17, 1.}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.3826834323650897, 0.9238795325112867}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.7071067811865475, 0.7071067811865476}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.9238795325112867, 0.38268343236508984}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-1., 1.2246467991473532*^-16}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.9238795325112868, -0.38268343236508967}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.7071067811865477, -0.7071067811865474}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-0.38268343236509034, -0.9238795325112865}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{-1.8369701987210297*^-16, -1.}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.38268343236509, -0.9238795325112866}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.7071067811865474, -0.7071067811865477}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{0.9238795325112865, -0.3826834323650904}, 0.05]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{1., -2.4492935982947064*^-16}, 0.05]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.5039684199579493, 0.}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.24155727517501757`, 0.5012857543232488}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.24877684075526632`, 0.6053950815696957}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.6227289741433344, 0.3796032612908802}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.7559526299369239, 7.55892096537123*^-17}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.6227289741433345, -0.3796032612908801}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.24877684075526663`, -0.6053950815696957}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.24155727517501716`, -0.5012857543232491}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.5039684199579493, -1.511784193074246*^-16}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.2415572751750179, 0.5012857543232486}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.24877684075526632`, 0.6053950815696957}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.6227289741433342, 0.37960326129088057`}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.7559526299369239, 2.267676289611369*^-16}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.6227289741433344, -0.3796032612908802}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.24877684075526676`, -0.6053950815696957}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.2415572751750166, -0.5012857543232495}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.5039684199579493, -3.023568386148492*^-16}]}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJyV1WtQVGUYB3ACDFFE8ELIqCGaqaODhairwIMJZqCDA4UJ5G3YFNGSNBER
EUWxmwGFOUIYJd6WBdPQRYWHizdSUFdQBJYFjsAWg6iIExaW9f73wx71Q8zs
8OHMOed9n/f//51Ryz8OVJqbmZllPf39+9+j23PZNudGMsPfpa0BBrVVI83R
9byX/iiXrs8aMPLdWD3NSx+4cPzFImobk7uxIKmBDmW97ni79gId6znubq3Q
UWak3SEL20rK6l3kNjWtjoZE+F3TrddSuN5as/in2+STVxv2XW41dX1qyImN
vEW9q1Sx49U1FNUVR3aPqmjmfIfCJ6vq6NjX8zP0/lqaE3Kxz++SjipXbvFb
1F5JFhmOq3f1a6SCIQ2h/f+4RC/XqLTKJ41UkjlaqagsJXfHD9/0rmiiqNC4
eerHGkrdc3m7Z3QzWTh12FsHHKa/ayO8pb+aKdjr1ejiwJWcNFPjYrlEonLt
0k7bhSqePsz+RF6mROt2rY1IiDvNnV6attGFErlO0d1Zn1rG09urW4vPSBS8
0ubm8Evl3LX8m6on6RKltexQtt+6yj19kxOUT5/3mXPK0U06Lcdk3y3dYSXR
+btOobvzq7ncrknxMK2Z1GMmrtsSVcOD8lwCfW2a6RVr68vttnX8tpX77H6r
m2j/uJzkki90bOXR21J5spGuHAp3ndSq5+QBs9dMrteTjX/iZn/bJlbEzC25
MLaBtg8Ouljh0MxLokqj/BbUU4b2sJmFjcSSxm34t6G1pOmas0DZIXFz8cRN
kf41lPB4uHvC6Tuc93j8gySXm3Q/41RS1yctHJSg2pgi3aAJQX8Wr3Bo5a/G
eeSOSrlObxQujN9zoJXfSdgd/HloJaVPGOXrM6KNyxY/rOuJLqew4KBI761t
rN48uzR+8znasCLLJ7yijUdWhVbdryuixJ/D1qRaGjhk1/2hET/+QoM2LPM9
+ZqBdQ9PeDWoDlBtZ31K2WQDd5+zjbHI2+dhj+ux4job739L3M/G5/cVz+cQ
vF8l3s/fY33nxfp4MtY/V6yfZfvje9j/IrF/ls2HCzA/ScyPMzFfvZgvJ2H+
H4j580CczzRxPnwN57dbnB+rcb7m4nx5hOn5cw7yYS/ywWyaH05EvjaJfPF+
0/zxUuTzgcgnuyO/CpFfPoJ83xP5ZocbIv/TRP7Z2dOkHzwY/ekV/eEv0a8U
0S8uRP+miv5xEfppKfrJjP72Ef3lbPQ7QPSbP0L/PUX/uQM+mEX+5wMvhR++
wg/+Ab44CV/Y6M9+4Q/LfGKjX3OFX2z0bYjwjY3+bfS5dyW+PPvsr7j+W73w
7wbu7w//DHh+Lvw7jvfvkfk3VOYfwb8e7K8b/q3C/r3hXw7m4w//bmN+L8G/
CszXAv7dwvzd4F+szD+F6fnRiRnifHfCP53MvwiZf/Q//dtimk86hvxWwL9T
yLfdC/w7gn5Ywr9S9Gcv/OuHftEL/JP1k/LR33aZf0fgn6z/z/jnCj+C4N8+
+FIP/4z+aGT+TYV/2+DX+zL/cmT+OWY5r02sL/IwXrfpFv5tx/2zZP7BV5b5
y8b1XYV/bli/F/ybhP1tg38y/zkR8zkI/2TfD87CfKvh307MPwz+yb5PLPt+
PePfaJy/L/wrQT5s4d8Z5Ocy/NuLfEXDv4My/1aY5pNnmOaXvU3zzbL8c5zC
pB8cMkz0x7xO+DcF/UqDf/no3zT4p0Y/reDfYfTXGv6p0G8/+Lca/SeZf+bw
Twk/vODfXvgyFv4dhT+n4J8En7Tw7wr8CpT5F/Nc//LP/gPB6Gjl
        "]]}}, {{}, {}}}}, 
   StyleBox[InsetBox["\<\"A\"\>", {0.88, 0.}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"B\"\>", {0.8130139886099323, 0.336761420481279}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"C\"\>", {0.6222539674441618, 0.6222539674441617}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"D\"\>", {0.33676142048127905, 0.8130139886099323}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"E\"\>", {5.388445916248354*^-17, 0.88}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"F\"\>", {-0.33676142048127894, 0.8130139886099323}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"G\"\>", {-0.6222539674441617, 0.6222539674441618}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"H\"\>", {-0.8130139886099323, 0.33676142048127905}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"I\"\>", {-0.88, 1.0776891832496708*^-16}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"J\"\>", {-0.8130139886099325, -0.33676142048127894}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"K\"\>", {-0.622253967444162, -0.6222539674441617}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"L\"\>", {-0.3367614204812795, -0.8130139886099321}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"M\"\>", {-1.616533774874506*^-16, -0.88}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"N\"\>", {0.3367614204812792, -0.8130139886099322}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"O\"\>", {0.6222539674441617, -0.622253967444162}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"P\"\>", {0.8130139886099321, -0.33676142048127955}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"A,I\"\>", {0.4132541043655184, 0.}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"B,J\"\>", {0.1980769656435144, 0.411054318545064}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"C,K\"\>", {-0.20399700941931836, 0.4964239668871504}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"D,L\"\>", {-0.5106377587975341, 0.31127467425852173}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"E,M\"\>", {-0.6198811565482776, 6.198315191604409*^-17}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"F,N\"\>", {-0.5106377587975343, -0.3112746742585217}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"G,O\"\>", {-0.20399700941931861, -0.4964239668871504}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"H,P\"\>", {0.19807696564351407, -0.4110543185450642}],
    FontFamily->"Times",
    FontSize->16]},
  AspectRatio->Automatic,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.8788150433274612`*^9, 3.8788150780342083`*^9, {3.878815109261922*^9, 
   3.878815157809925*^9}, 3.878815297440476*^9, {3.878815533761681*^9, 
   3.878815607175946*^9}, 3.878815882569047*^9, 3.878815926207428*^9, {
   3.878815980638259*^9, 3.878816088667932*^9}, 3.878816159281824*^9, 
   3.878817731515851*^9, 3.87881964065965*^9, 3.878819808801153*^9, {
   3.878820081407777*^9, 3.878820102044186*^9}, 3.878820413201889*^9, 
   3.8788204748011837`*^9, 3.878820741664439*^9, 3.878821097870431*^9, 
   3.878821191835058*^9, 3.890987264825189*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"541f7000-9162-4bff-af1d-c6e9c3a7ffc5"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPathRotating", "Input"],
 " to show the paths in the rotating frame around the resonant orbit, adding \
points at equal time intervals, ",
 StyleBox["dt", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878806258410295*^9, 3.8788062594003763`*^9}, 
   3.8788190749945507`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"94687d85-cdaa-44ab-98c2-0c1df41de9b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotPathRotating", "[", 
   RowBox[{"pl_List", ",", " ", "e_", ",", " ", "dt_"}], "]"}], " ", ":=", 
  "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"Apply", "[", 
        RowBox[{"Rational", ",", 
         RowBox[{"Reverse", "[", "pl", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"pt", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pl", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", ">", " ", 
          RowBox[{"pl", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
         RowBox[{"pl", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
         RowBox[{"pl", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"sun", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.15", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], ",", 
      RowBox[{"planet", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Thickness", "[", "0.005", "]"}], "]"}], ",", "color2", 
          ",", 
          RowBox[{"Disk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "0"}], "}"}], ",", "0.05"}], "]"}]}], "}"}], 
        "]"}]}], ",", 
      RowBox[{"porb", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"color2", ",", "Dashed", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pl", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "/", 
           RowBox[{"pl", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", "/", "3"}], ")"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"box", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1.1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.1", ",", 
             RowBox[{"-", "1.1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.1", ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1.1"}]}], "}"}]}], "}"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"time", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"pt", "*", "2", "*", "Pi"}], ",", "dt"}], "}"}]}], "]"}]}], 
     ";", 
     RowBox[{"ptime", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"pt", "*", "2", "*", "Pi"}], ",", 
          RowBox[{"Pi", "/", "40"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"posvec", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "[", 
          RowBox[{"#", ",", "a", ",", "e"}], "]"}], "&"}], ",", "time"}], 
       "]"}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "posvec"}], "]"}]}], ";", 
     RowBox[{"rad", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}], 
         "&"}], ",", "posvec"}], "]"}]}], ";", 
     RowBox[{"points", " ", "=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"f", "-", 
            RowBox[{"time", "/", "p"}]}], "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"f", "-", 
            RowBox[{"time", "/", "p"}]}], "]"}]}]}], "}"}], "]"}]}], ";", 
     RowBox[{"apoints", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", "0.02", "]"}], ",", "color1", ",", 
            RowBox[{"Point", "[", "#", "]"}]}], "}"}], "]"}], "&"}], ",", 
        "points"}], "]"}]}], ";", 
     RowBox[{"posvec", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "[", 
          RowBox[{"#", ",", "a", ",", "e"}], "]"}], "&"}], ",", "ptime"}], 
       "]"}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "posvec"}], "]"}]}], ";", " ", 
     RowBox[{"rad", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}], 
         "&"}], ",", "posvec"}], "]"}]}], ";", 
     RowBox[{"orbpts", " ", "=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"f", "-", 
            RowBox[{"ptime", "/", "p"}]}], "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"f", "-", 
            RowBox[{"ptime", "/", "p"}]}], "]"}]}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p3", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"orbpts", ",", 
        RowBox[{"Joined", "->", "True"}], ",", 
        RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
        RowBox[{"Axes", "->", "None"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}]}], "]"}]}], 
     ";", " ", 
     RowBox[{"Show", "[", 
      RowBox[{
      "box", ",", "sun", ",", "porb", ",", "planet", ",", "apoints", ",", 
       "p3", ",", 
       RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
       RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.878551615873766*^9, 3.878551620210084*^9}, {
   3.878806250793545*^9, 3.878806277403981*^9}, {3.878806340162304*^9, 
   3.8788063433133497`*^9}, {3.878806639455246*^9, 3.878806641346648*^9}, 
   3.8788096833101482`*^9, {3.878816481056576*^9, 3.8788165565636263`*^9}, {
   3.8788166011869097`*^9, 3.878816670773677*^9}, {3.878816708460532*^9, 
   3.878816752014783*^9}, {3.878817662183223*^9, 3.878817680091957*^9}, {
   3.878817811146936*^9, 3.878817817987708*^9}, {3.8788179371020727`*^9, 
   3.878818037870994*^9}, {3.87881807752077*^9, 3.878818104984424*^9}, {
   3.878818144420272*^9, 3.8788181451058903`*^9}, {3.878819593355302*^9, 
   3.8788195944945602`*^9}, 3.878820228822835*^9, {3.878820287303019*^9, 
   3.8788202878095703`*^9}, {3.878820358734241*^9, 3.878820372858612*^9}, {
   3.87882043623662*^9, 3.8788204571296167`*^9}, {3.878820509859828*^9, 
   3.878820657591133*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"8c792154-0166-41ee-84ff-50a529d9e698"],

Cell["\<\
Plot the path in the rotating frame for the 2:1 resonance with points at time \
intervals of \[Pi]/4. Note that in the rotating frame the location of the \
perturber (Jupiter in our example) is fixed because it moves with constant \
angular velocity in its circular orbit in the non-rotating frame.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8788199804274797`*^9, 3.878820023570215*^9}, {
  3.878821004685628*^9, 3.878821062981456*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1d7e7c5b-3064-4e78-a539-d276292cf494"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prot", " ", "=", " ", 
  RowBox[{"PlotPathRotating", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", " ", "0.2", ",", " ", 
    RowBox[{"Pi", "/", "4"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.878551639164755*^9, 3.8785516391701527`*^9}, {
  3.878806243951642*^9, 3.8788062456460752`*^9}, {3.8788183184440813`*^9, 
  3.878818319192752*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"2c6db937-359b-4867-b2a2-469804bf2c5d"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
    1.1}, {-1.1, -1.1}}], 
   {PointSize[0.15], PointBox[{0, 0}]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Dashing[{Small, Small}], 
    CircleBox[{0, 0}, 1]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
    DiskBox[{1, 0}, 0.05]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.5039684199579493, 0.}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.41500357552353956`, 0.3706876811819967}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.2521671763747002, 0.6039907585751296}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.1123996223228156, 0.720594432480553}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{4.6288748427963873`*^-17, 0.7559526299369239}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.11239962232281572`, 0.7205944324805531}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.25216717637470004`, 0.6039907585751297}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.4150035755235392, 0.370687681181997}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.5039684199579493, 1.6208860617122506`*^-16}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.4150035755235398, -0.3706876811819963}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.2521671763747001, -0.6039907585751296}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-0.11239962232281585`, -0.720594432480553}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{-2.8942165768480144`*^-16, -0.7559526299369239}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.11239962232281578`, -0.720594432480553}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.2521671763747002, -0.6039907585751298}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.41500357552353906`, -0.3706876811819974}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    PointBox[{0.5039684199579493, -3.241772123424501*^-16}]}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVln9UzXcYx5ssHeTHTpNfRU0/sLpxLFm1Z8OEmU6FMkJW4fRTReNMqpVy
W3LNz8mvk1UYy4Rjcp6ZdGJGud2iVFd1uzeSQ7tsZ2Jbz/v+cTvnnv74nu/3
83ye9/v9eh7H1fFBkf0sLCyO/ff7/7+v0S88Y7yWLPDnueK840s7Le0csGb3
lebjZM/v+Fv3ttBU9yP6/D/KaOtwdUzkiRYK6d+TazWQKc/R+ttyrxZ6S3Mu
pExZQV39DxkWFjfTjMLSin7rb5Dh4jBlVW8TpbYVBdpOvU2ZE52GOvg1UdS0
06dVETW0v2TfmOi1D6j69Pi9nxxQ08srO+6pMxppzt/7Mm6e11CNwsUtOr+B
onye3A29VE/9V3kvdlDdp6VecaVZhfcp+2xAUJHyHv18xGPGnORGiu5pGpma
Wk+6wgeBDZOb6N3Vh2Oa4uqop9nJt/xmM22Pr3a5GKahUN86TZWbljx9ktx/
WVBL6UnRK/O1WuoIUwYs8lPThJLwrfZ5D+narh0rLnjeJU1mhEe7RysNifN8
c8+1huIWzLdcUtlKbo2dv6e/V00zgyNj24PbyCXlfQvV3Nvk/eHgY731beRw
+a/n0xffooQTW0YOCm6nEqrS5sXepHhNaF7C9XZq/eF1sUFVRX/+2BOYq9CR
TUpJVtRvleQ7fLbxrEpHB4I2+BhfV9C8hJRx07p0NOHwmPWh/teoIGnz/i+o
gzIPjg5THLxKk9y2xKzJ7aDElIE5PT1MqlO6CXurO8hGZbziXVlO6VrnIWOH
6qmgOzv5xqlLlGfMz3Tz15ONrd+MUYUXaPWmglm6r/R05mmVzeaT52jZc5ey
jcf1NHH03POOv5aSsvS116sbenrR7F+7vOIUWY1Qr9vZqadKq5BJS+yLKKDu
7ch5lgb6MjLZ2yX7KN2JCHrmbWcgdVdEUsg/e2hT8rayGGcDrXvk437neRYl
JV9d1O1uIGPFkE2WPyl9G54+UF3zNNDXnX3PORHP8+R93oz3l8r32fT9Y3I+
f47z7Vv66mNr1KeQ+jkH9Z+Q+7HpfjPl/hyO+6dJf3gH+mMr/eMM9C9W+sum
/qZK/9kd/fcQffgQ9Nkl+vFn0K9rY5++TNC3UfTnF9D/pPiD4+AP+Ifj4B9v
8Rd7wV/O4j+eBf8NFH+yyZ/Xxb9cB/+2ir95IvztJv7nb+B/peSDQ5CPEZIf
7kZ+EiVf/BD52ib54wvIn5XkkwORz1uSX45Bfnsk3xyAfO+V/LMa+U8TPvBa
8EEn/OA08AN84Y/BF/CHLcCfVOETLwOfwC/2AL8UwjeOBt/AP64pcfzecnmx
7xQ8J3nOY/G+lbzPafh+pHyfTef31vadz49Rn4/Ux52of4PUz1m43yq5H+/B
/Wvl/mxEfxZKf1iD/q2U/rE1+hsk/eUc9P+M9J/joU+r6MN20K9L9ONc6LtE
9GUF9Af/WAd/OIs/GPzjevEPD4W/YsVf7AL/gX88xdyf7AX/xoh/uRj+ThB/
cwv8bxT/8yvzfPBR5Geu5IddzfPF6cgf+MerzPPJ45Bf8I/XI9/gHzsg/+Af
nzPnAwea84OngC8DhC+sB38WCn/4I3M+sd0T4VeK8IuHg2/gH/vYXXZqaygr
B//4g8dmfOQic35ylDlfedgA4a/pfNcWMz6zF/i9HfWng+9huN8oc/5zNuZD
Pvoz2nx+8KeYL7vQ3zTMn8novwLz6SD02Y35NR/6PRV9yaRvM+Yf+McFmI+J
8IcT5mc8/GOL+eoDf7li/s6G/wZjPsfDn5WY3+AfP8N8Hw9/T8X8T4P/v8N+
EIx8DML+8Ab5icJ+0Y18mfYP8I97V8p+Eo58VmF/SUJ+kW+ah3zvxv6jQf63
Yj+KBR8eYX+KBz8M2K8Wgy852L8chH8mPtF28Gkk9rfp4Jdpv/sGfDPtf8K/
i+X/AuqlSsk=
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.8785516401170197`*^9, 3.8785611498525257`*^9, 3.878562488519175*^9, 
   3.8788180459413567`*^9, {3.8788180825408497`*^9, 3.878818112134088*^9}, 
   3.87881832582755*^9, 3.878819640965123*^9, {3.878819790791923*^9, 
   3.8788198090332537`*^9}, {3.878820081623845*^9, 3.878820102386904*^9}, 
   3.8788202734487677`*^9, 3.878820413598467*^9, 3.878820475143815*^9, 
   3.8788207418084784`*^9, 3.878821097945421*^9, 3.878821191910425*^9, 
   3.890987265061369*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"b38954d1-29bc-408a-9cac-6a84bf6ad500"]
}, Open  ]],

Cell[TextData[{
 "Define the labels to be used in the rotating frame plot, using the points \
derived in the ",
 StyleBox["PlotPathRotating", "Input"],
 " function."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8788192962883167`*^9, 3.878819317437983*^9}, {
   3.878820951392358*^9, 3.878820974610874*^9}, 3.878821121132347*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2a89b252-4862-4108-b458-a758761cf3d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aangles", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"1.13", "*", "points"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878818752196381*^9, 3.878818774980105*^9}, {
  3.878818824570698*^9, 3.878818842645657*^9}, {3.878818942773622*^9, 
  3.878819020080235*^9}, {3.8788197665603247`*^9, 3.8788197728893137`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"f5b3e7d8-1636-48aa-b680-5f83b16b943a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"alabels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "\"\<D\>\"", ",", 
     "\"\<E\>\"", ",", "\"\<F\>\"", ",", "\"\<G\>\"", ",", "\"\<H\>\"", ",", 
     "\"\<I\>\"", ",", "\"\<J\>\"", ",", "\"\<K\>\"", ",", "\"\<L\>\"", ",", 
     "\"\<M\>\"", ",", "\"\<N\>\"", ",", "\"\<O\>\"", ",", "\"\<P\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.87881831407819*^9, 3.878818314453541*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"02cc698b-9b18-4611-b9d5-51aabbca7016"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aletters", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"alabels", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"aangles", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "16"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.878818889116084*^9, 3.878818896930273*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"345b0bf7-b72d-4814-87e1-f5a71aa44fb2"],

Cell["\<\
Add the labels to help to identify the location in the rotating frame at each \
time step.  This is Fig.8.3b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878819122724942*^9, 3.878819259463366*^9}, {
  3.878820043533126*^9, 3.878820048511554*^9}, {3.878820686146308*^9, 
  3.878820686611238*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5c1af9b1-eb4a-4f6d-8674-8c527f98fabf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"prot", ",", "aletters"}], "]"}]], "Input",
 CellChangeTimes->{{3.8788189220860043`*^9, 3.878818930500149*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"59f2ccd0-53bc-4ba0-b314-8d25acbbfba7"],

Cell[BoxData[
 GraphicsBox[{{
    LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
     1.1}, {-1.1, -1.1}}], 
    {PointSize[0.15], PointBox[{0, 0}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], Dashing[{Small, Small}], 
     CircleBox[{0, 0}, 1]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[Thickness[0.005]], 
     DiskBox[{1, 0}, 0.05]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.5039684199579493, 0.}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.41500357552353956`, 0.3706876811819967}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.2521671763747002, 0.6039907585751296}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.1123996223228156, 0.720594432480553}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{4.6288748427963873`*^-17, 0.7559526299369239}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.11239962232281572`, 0.7205944324805531}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.25216717637470004`, 0.6039907585751297}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.4150035755235392, 0.370687681181997}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.5039684199579493, 1.6208860617122506`*^-16}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.4150035755235398, -0.3706876811819963}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.2521671763747001, -0.6039907585751296}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-0.11239962232281585`, -0.720594432480553}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{-2.8942165768480144`*^-16, -0.7559526299369239}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.11239962232281578`, -0.720594432480553}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.2521671763747002, -0.6039907585751298}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.41500357552353906`, -0.3706876811819974}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     PointBox[{0.5039684199579493, -3.241772123424501*^-16}]}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxVln9UzXcYx5ssHeTHTpNfRU0/sLpxLFm1Z8OEmU6FMkJW4fRTReNMqpVy
W3LNz8mvk1UYy4Rjcp6ZdGJGud2iVFd1uzeSQ7tsZ2Jbz/v+cTvnnv74nu/3
83ye9/v9eh7H1fFBkf0sLCyO/ff7/7+v0S88Y7yWLPDnueK840s7Le0csGb3
lebjZM/v+Fv3ttBU9yP6/D/KaOtwdUzkiRYK6d+TazWQKc/R+ttyrxZ6S3Mu
pExZQV39DxkWFjfTjMLSin7rb5Dh4jBlVW8TpbYVBdpOvU2ZE52GOvg1UdS0
06dVETW0v2TfmOi1D6j69Pi9nxxQ08srO+6pMxppzt/7Mm6e11CNwsUtOr+B
onye3A29VE/9V3kvdlDdp6VecaVZhfcp+2xAUJHyHv18xGPGnORGiu5pGpma
Wk+6wgeBDZOb6N3Vh2Oa4uqop9nJt/xmM22Pr3a5GKahUN86TZWbljx9ktx/
WVBL6UnRK/O1WuoIUwYs8lPThJLwrfZ5D+narh0rLnjeJU1mhEe7RysNifN8
c8+1huIWzLdcUtlKbo2dv6e/V00zgyNj24PbyCXlfQvV3Nvk/eHgY731beRw
+a/n0xffooQTW0YOCm6nEqrS5sXepHhNaF7C9XZq/eF1sUFVRX/+2BOYq9CR
TUpJVtRvleQ7fLbxrEpHB4I2+BhfV9C8hJRx07p0NOHwmPWh/teoIGnz/i+o
gzIPjg5THLxKk9y2xKzJ7aDElIE5PT1MqlO6CXurO8hGZbziXVlO6VrnIWOH
6qmgOzv5xqlLlGfMz3Tz15ONrd+MUYUXaPWmglm6r/R05mmVzeaT52jZc5ey
jcf1NHH03POOv5aSsvS116sbenrR7F+7vOIUWY1Qr9vZqadKq5BJS+yLKKDu
7ch5lgb6MjLZ2yX7KN2JCHrmbWcgdVdEUsg/e2hT8rayGGcDrXvk437neRYl
JV9d1O1uIGPFkE2WPyl9G54+UF3zNNDXnX3PORHP8+R93oz3l8r32fT9Y3I+
f47z7Vv66mNr1KeQ+jkH9Z+Q+7HpfjPl/hyO+6dJf3gH+mMr/eMM9C9W+sum
/qZK/9kd/fcQffgQ9Nkl+vFn0K9rY5++TNC3UfTnF9D/pPiD4+AP+Ifj4B9v
8Rd7wV/O4j+eBf8NFH+yyZ/Xxb9cB/+2ir95IvztJv7nb+B/peSDQ5CPEZIf
7kZ+EiVf/BD52ib54wvIn5XkkwORz1uSX45Bfnsk3xyAfO+V/LMa+U8TPvBa
8EEn/OA08AN84Y/BF/CHLcCfVOETLwOfwC/2AL8UwjeOBt/AP64pcfzecnmx
7xQ8J3nOY/G+lbzPafh+pHyfTef31vadz49Rn4/Ux52of4PUz1m43yq5H+/B
/Wvl/mxEfxZKf1iD/q2U/rE1+hsk/eUc9P+M9J/joU+r6MN20K9L9ONc6LtE
9GUF9Af/WAd/OIs/GPzjevEPD4W/YsVf7AL/gX88xdyf7AX/xoh/uRj+ThB/
cwv8bxT/8yvzfPBR5Geu5IddzfPF6cgf+MerzPPJ45Bf8I/XI9/gHzsg/+Af
nzPnAwea84OngC8DhC+sB38WCn/4I3M+sd0T4VeK8IuHg2/gH/vYXXZqaygr
B//4g8dmfOQic35ylDlfedgA4a/pfNcWMz6zF/i9HfWng+9huN8oc/5zNuZD
Pvoz2nx+8KeYL7vQ3zTMn8novwLz6SD02Y35NR/6PRV9yaRvM+Yf+McFmI+J
8IcT5mc8/GOL+eoDf7li/s6G/wZjPsfDn5WY3+AfP8N8Hw9/T8X8T4P/v8N+
EIx8DML+8Ab5icJ+0Y18mfYP8I97V8p+Eo58VmF/SUJ+kW+ah3zvxv6jQf63
Yj+KBR8eYX+KBz8M2K8Wgy852L8chH8mPtF28Gkk9rfp4Jdpv/sGfDPtf8K/
i+X/AuqlSsk=
        "]]}}, {{}, {}}}}, 
   StyleBox[InsetBox["\<\"A\"\>", {0.5694843145524826, 0}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"B\"\>", {0.46895404034159965, 0.41887707973565624}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"C\"\>", {0.2849489093034112, 0.6825095571898964}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"D\"\>", {0.12701157322478163, 0.8142717087030248}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"E\"\>", {0, 0.8542264718287239}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"F\"\>", {-0.12701157322478177, 0.8142717087030249}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"G\"\>", {-0.28494890930341105, 0.6825095571898966}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"H\"\>", {-0.46895404034159927, 0.4188770797356566}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"I\"\>", {-0.5694843145524826, 0}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"J\"\>", {-0.46895404034159993, -0.4188770797356558}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"K\"\>", {-0.2849489093034111, -0.6825095571898964}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"L\"\>", {-0.1270115732247819, -0.8142717087030248}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"M\"\>", {0, -0.8542264718287239}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"N\"\>", {0.12701157322478182, -0.8142717087030248}],
    
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"O\"\>", {0.2849489093034112, -0.6825095571898967}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[InsetBox["\<\"P\"\>", {0.4689540403415991, -0.418877079735657}],
    FontFamily->"Times",
    FontSize->16]},
  AspectRatio->Automatic,
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.878818931533826*^9, 3.87881902896658*^9}, 
   3.878819641041751*^9, {3.8788197947214108`*^9, 3.878819809095126*^9}, {
   3.878820081673044*^9, 3.878820102456959*^9}, 3.8788202763891563`*^9, 
   3.8788204136704082`*^9, 3.87882047516607*^9, 3.878820741947353*^9, 
   3.878821097991564*^9, 3.878821192106505*^9, 3.890987265423889*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"7d057e79-91d9-4e54-a902-ad3306aaf6ed"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1051, 666},
WindowMargins->{{85, Automatic}, {Automatic, 22}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8840aedf-7ff6-4211-b87c-c7ab7b86d3a4"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"19c3120b-2ac8-4eea-ad9f-e07fdfb682f6"],
Cell[1000, 31, 230, 4, 67, "Section",ExpressionUUID->"116b32ce-d651-44c4-a052-edcb74a1d02b"],
Cell[1233, 37, 319, 8, 49, "Text",ExpressionUUID->"0757cbff-c8b9-4496-aced-052489c24451"],
Cell[1555, 47, 553, 14, 30, "Input",ExpressionUUID->"e1653a61-6b1c-42de-a1e8-135f0be0a02e"],
Cell[2111, 63, 369, 13, 53, "Text",ExpressionUUID->"b9b27efc-2e00-4c43-8ea3-cd301bfd5c4a"],
Cell[2483, 78, 945, 27, 94, "Input",ExpressionUUID->"539b69c8-8625-4600-adc5-c07ae65568da"],
Cell[3431, 107, 459, 9, 53, "Text",ExpressionUUID->"9b8ea8fc-ab2e-491a-af25-0c30d05ca6bb"],
Cell[3893, 118, 496, 13, 52, "Input",ExpressionUUID->"ba917d24-c5bd-405b-8096-ef18d10a00c0"],
Cell[4392, 133, 399, 9, 53, "Text",ExpressionUUID->"1945fe94-8110-4045-9be7-32cbe9e3485e"],
Cell[4794, 144, 318, 7, 33, "Input",ExpressionUUID->"bccf7402-2890-4b34-bf7c-4604b5d4ae7e"],
Cell[5115, 153, 314, 7, 33, "Input",ExpressionUUID->"dee6dc8b-7e87-49bc-a336-26c04af5ddd9"],
Cell[5432, 162, 439, 11, 76, "Text",ExpressionUUID->"e82385bb-d636-4c19-8cab-b138bf7f95b0"],
Cell[5874, 175, 9956, 260, 556, "Input",ExpressionUUID->"df636d44-0d64-4c40-a000-18c6f1bd180d"],
Cell[15833, 437, 325, 7, 53, "Text",ExpressionUUID->"45542096-61ae-4fd8-a06d-08cc0d684967"],
Cell[CellGroupData[{
Cell[16183, 448, 530, 10, 30, "Input",ExpressionUUID->"4c6a7114-81b5-45fe-be3b-9e879f1d94fc"],
Cell[16716, 460, 7294, 118, 377, "Output",ExpressionUUID->"7840c6e3-907c-4207-a806-89d80075b7ae"]
}, Open  ]],
Cell[24025, 581, 256, 4, 53, "Text",ExpressionUUID->"2207161e-5767-423c-88d1-519c317c13bc"],
Cell[24284, 587, 716, 18, 30, "Input",ExpressionUUID->"a4153d95-f66c-4fef-a902-6780e6849f9a"],
Cell[25003, 607, 563, 11, 30, "Input",ExpressionUUID->"cd3aea0b-6b73-4e3e-b390-316dfa5ec12c"],
Cell[25569, 620, 998, 24, 30, "Input",ExpressionUUID->"825e2e3e-4a63-46cc-91b2-f58f2fde7328"],
Cell[26570, 646, 886, 19, 30, "Input",ExpressionUUID->"50a2d504-96e4-4a76-b11f-6f31e53b0ac1"],
Cell[27459, 667, 524, 11, 30, "Input",ExpressionUUID->"57c00776-ce55-46d5-bce6-b11c57d5c36b"],
Cell[27986, 680, 1093, 25, 30, "Input",ExpressionUUID->"3c89c47a-d412-4d4c-ba18-b92a686fa542"],
Cell[29082, 707, 293, 7, 53, "Text",ExpressionUUID->"8a83918a-488d-47e9-92e2-38aeccfa6e92"],
Cell[CellGroupData[{
Cell[29400, 718, 458, 7, 30, "Input",ExpressionUUID->"1d782ee5-6294-4d71-b7b9-499bb41f0461"],
Cell[29861, 727, 10273, 195, 377, "Output",ExpressionUUID->"541f7000-9162-4bff-af1d-c6e9c3a7ffc5"]
}, Open  ]],
Cell[40149, 925, 441, 12, 53, "Text",ExpressionUUID->"94687d85-cdaa-44ab-98c2-0c1df41de9b4"],
Cell[40593, 939, 8982, 242, 451, "Input",ExpressionUUID->"8c792154-0166-41ee-84ff-50a529d9e698"],
Cell[49578, 1183, 549, 10, 76, "Text",ExpressionUUID->"1d7e7c5b-3064-4e78-a539-d276292cf494"],
Cell[CellGroupData[{
Cell[50152, 1197, 477, 10, 30, "Input",ExpressionUUID->"2c6db937-359b-4867-b2a2-469804bf2c5d"],
Cell[50632, 1209, 5186, 89, 376, "Output",ExpressionUUID->"b38954d1-29bc-408a-9cac-6a84bf6ad500"]
}, Open  ]],
Cell[55833, 1301, 427, 10, 53, "Text",ExpressionUUID->"2a89b252-4862-4108-b458-a758761cf3d0"],
Cell[56263, 1313, 431, 8, 30, "Input",ExpressionUUID->"f5b3e7d8-1636-48aa-b680-5f83b16b943a"],
Cell[56697, 1323, 562, 11, 30, "Input",ExpressionUUID->"02cc698b-9b18-4611-b9d5-51aabbca7016"],
Cell[57262, 1336, 824, 21, 30, "Input",ExpressionUUID->"345b0bf7-b72d-4814-87e1-f5a71aa44fb2"],
Cell[58089, 1359, 407, 9, 53, "Text",ExpressionUUID->"5c1af9b1-eb4a-4f6d-8674-8c527f98fabf"],
Cell[CellGroupData[{
Cell[58521, 1372, 237, 4, 30, "Input",ExpressionUUID->"59f2ccd0-53bc-4ba0-b314-8d25acbbfba7"],
Cell[58761, 1378, 7043, 142, 399, "Output",ExpressionUUID->"7d057e79-91d9-4e54-a902-ad3306aaf6ed"]
}, Open  ]]
}
]
*)

